define("ContactSectionV2", [],
function() {
	return {
		// Название схемы объекта раздела.
		entitySchemaName: "Contact",
		// Коллекция методов модели представления раздела.
		methods: {
			// Метод-обработчик нажатия кнопки.
			onSelectQueryContactClick: function() {
				// Создание экземпляра класса Terrasoft.InsertQuery.
				var select = Ext.create("Terrasoft.EntitySchemaQuery", {
					// Название корневой схемы.
					rootSchemaName: "Contact"
				});
				// Добавление в запрос колонки [ФИО].
				select.addColumn("Name");
				// Добавление в запрос агрегирующей колонки [Количество активностей].
				select.addAggregationSchemaColumn(
					// Путь к колонке относительно корневой схемы.
					"[Activity:Contact].Id",
					// Тип агрегации — количество.
					Terrasoft.AggregationType.COUNT,
					// Заголовок колонки.
					"ActivitiesCount",
					// Область применения агрегирующей функции — для всех элементов.
					Terrasoft.AggregationEvalType.ALL);
				// Запрос к серверу на обновление данных
				// Получение всей коллекции записей и ее отображение в консоли браузера.
				select.getEntityCollection(function(result) {
					if (!result.success) {
						// Обработка/логирование ошибки.
						this.showInformationDialog("Ошибка запроса данных");
						return;
					}
					// Выводимое сообщение.
					var message = "";
					// Перебор результирующей коллекции и построение выводимого сообщения.
					result.collection.each(function(item) {
						message += "ФИО: " + item.get("Name") +
						". Количество активностей: " + item.get("ActivitiesCount") + "\n";
					});
					// Вывод сообщения в консоль.
					window.console.log(message);
				}, this);
			}
		},
		//Настройка визуализации кнопки в разделе.
		diff: /**SCHEMA_DIFF*/[
			// Метаданные для добавления в раздел пользовательской кнопки.
			{
				// Указывает на то, что выполняется операция добавления элемента на страницу.
				"operation": "insert",
				// Мета-имя родительского элемента управления, в который добавляется кнопка.
				"parentName": "ActionButtonsContainer",
				// Указывает на то, что кнопка добавляется в коллекцию элементов управления
				// родительского элемента (мета-имя которого указано в parentName).
				"propertyName": "items",
				// Мета-имя добавляемой кнопки.
				"name": "SelectQueryContactButton",
				// Дополнительные свойства элемента.
				"values": {
					// Тип добавляемого элемента - кнопка.
					itemType: Terrasoft.ViewItemType.BUTTON,
					// Привязка заголовка кнопки к локализуемой строке схемы.
					caption: { bindTo: "Resources.Strings.SelectQueryContactButtonCaption" },
					// Привязка метода-обработчика нажатия кнопки.
					click: { bindTo: "onSelectQueryContactClick" },
					"layout": {
						"column": 1,
						"row": 6,
						"colSpan": 1
					}
				}
			}

		]/**SCHEMA_DIFF*/
	};
});